<?php
/**
 * @copyright: Copyright © 2021 Firebear Studio. All rights reserved.
 * @author   : Firebear Studio <fbeardev@gmail.com>
 */
namespace Firebear\PlatformSap\Model\Import;

use Firebear\ImportExport\Model\Import\SalesRule as SalesRuleBase;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\Serialize\Serializer\Json as Serializer;
use Magento\Customer\Model\ResourceModel\Group\CollectionFactory as GroupCollectionFactory;
use Magento\SalesRule\Model\ResourceModel\RuleFactory as RuleResourceFactory;
use Magento\SalesRule\Model\RuleFactory;
use Magento\ImportExport\Model\ImportFactory;
use Magento\Rule\Model\ConditionFactory;
use Magento\Rule\Model\ActionFactory;
use Firebear\ImportExport\Model\Import\Context;
use Firebear\ImportExport\Helper\Data as ImportExportHelper;

/**
 * SalesRule import
 */
class SalesRule extends SalesRuleBase
{
    /**
     * Field list
     *
     * @var array
     */
    protected $fields = [
        'name',
        'code',
        'uses_per_coupon',
        'description',
        'from_date',
        'to_date',
        'uses_per_customer',
        'customer_group_ids',
        'is_active',
        'stop_rules_processing',
        'sort_order',
        'simple_action',
        'discount_amount',
        'discount_step',
        'discount_qty',
        'simple_free_shipping',
        'apply_to_shipping',
        'times_used',
        'is_rss',
        'coupon_type',
        'use_auto_generation',
        'website_ids',
        'store_labels',
        'sap_id'
    ];

    /**
     * @var ImportExportHelper
     */
    protected $_helper;

    /**
     * SalesRule constructor.
     * @param Context $context
     * @param ScopeConfigInterface $scopeConfig
     * @param ImportFactory $importFactory
     * @param RuleFactory $ruleFactory
     * @param ConditionFactory $conditionFactory
     * @param ActionFactory $actionFactory
     * @param Serializer $serializer
     * @param GroupCollectionFactory $groupCollectionFactory
     * @param RuleResourceFactory $ruleResourceFactory
     * @param ImportExportHelper $helper
     * @param array $data
     */
    public function __construct(
        Context $context,
        ScopeConfigInterface $scopeConfig,
        ImportFactory $importFactory,
        RuleFactory $ruleFactory,
        ConditionFactory $conditionFactory,
        ActionFactory $actionFactory,
        Serializer $serializer,
        GroupCollectionFactory $groupCollectionFactory,
        RuleResourceFactory $ruleResourceFactory,
        ImportExportHelper $helper,
        array $data = []
    ) {
        $this->_helper = $helper;
        parent::__construct(
            $context,
            $scopeConfig,
            $importFactory,
            $ruleFactory,
            $conditionFactory,
            $actionFactory,
            $serializer,
            $groupCollectionFactory,
            $ruleResourceFactory,
            $data
        );
    }
}
