<?php
/**
 * Copyright © Firebear Studio, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace Firebear\PlatformSap\Model\Import\Source;

use Magento\Framework\Exception\LocalizedException;

/**
 * Sap product source
 */
class CustomerGroup extends AbstractSource
{
    const DEFAULT_TAX_CLASS_ID = 3;

    /**
     * @var Gateway\CustomerGroup
     */
    protected $gateway;

    /**
     * Config data
     *
     * @var array
     */
    protected $_data = [];

    /**
     * @var \Magento\Framework\App\RequestInterface
     */
    protected $request;

    /**
     * CustomerGroup constructor.
     * @param Gateway\CustomerGroup $gateway
     * @param \Magento\Framework\App\RequestInterface $request
     * @param null $data
     * @throws \Exception
     */
    public function __construct(
        \Firebear\PlatformSap\Model\Import\Source\Gateway\CustomerGroup $gateway,
        \Magento\Framework\App\RequestInterface $request,
        $data = null
    ) {
        $this->gateway = $gateway;
        $this->request = $request;
        $this->parseEntities($data);
    }

    /**
     * @param $data
     * @return array|bool
     * @throws \Exception
     */
    protected function parseEntities($data)
    {
        $this->entities = parent::parseEntities($data);
        if (!empty($this->entities)) {
            foreach ($this->entities as $key => $entity) {
                if (isset($entity['GroupName'])) {
                    $this->entities[$key]['customer_group_code'] = $entity['GroupName'];
                }
                if (isset($entity['GroupCode'])) {
                    $this->entities[$key]['sap_id'] = $entity['GroupCode'];
                }
                $this->entities[$key]['tax_class_id'] = self::DEFAULT_TAX_CLASS_ID;
            }
        }
        $this->_colNames = array_keys($this->entities[0] ?? []);
        return $this->entities;
    }
}
