<?php
/**
 * Copyright © Firebear Studio, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace Firebear\PlatformSap\Model\Import\Source\Gateway;

/**
 * Sap abstract gateway
 */
class AbstractGateway extends \Firebear\ImportExport\Model\Source\Type\Rest
{
    /**
     * @param $data
     * @return false|mixed
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function uploadPartSource($data)
    {
        $this->client = null;
        if ($client = $this->_getSourceClient()) {
            $fileMetadata = $this->getSourceData($data);
            if ($fileMetadata) {
                return $fileMetadata;
            } else {
                return false;
            }
        } else {
            throw new  \Magento\Framework\Exception\LocalizedException(__("Can't initialize %s client", $this->code));
        }
    }

    /**
     * @param string $data Json request body from Job's settings
     * @param null|string $type
     * @param null $format
     *
     * @return mixed json-structured data
     */
    public function convertToFormat($data, $type = null, $format = null)
    {
        $data = [];
        $data = json_encode($data);
        return parent::convertToFormat($data, $type, $format);
    }

    /**
     * @param $data
     * @return false|mixed
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function getSourceData($data)
    {
        $url = 'http://%s:%s/B1iXcellerator/exec/ipo/vP.%s.in_HCSX/com.sap.b1i.vplatform.runtime/'.
            '%s/%s.ipo/proc/%s';

        $params = [];
        if (isset($data['sap_additional_params'])) {
            foreach ($data['sap_additional_params'] as $additional_param => $value) {
                $params[$additional_param] = $value;
            }
        }
        $params['limit'] = !empty($data['limit']) ? $data['limit'] : 100;
        $params['page'] = $data['page'];

        $sourceData = $this->_getSourceClient()->execute(
            sprintf(
                $url,
                $data['sap_server_ip'],
                $data['sap_server_port'],
                $data['sap_system_id'],
                $data['sap_order_ipo'],
                $data['sap_order_ipo'],
                $data['sap_entity_endpoint']
            ),
            'GET',
            $params
        );
        if ($sourceData && false !== $sourceData->response) {
            $sourceData = json_decode($sourceData->response, true);
            return $sourceData;
        } else {
            $errorMessage = __("No content from API call");
            throw new \Magento\Framework\Exception\LocalizedException($errorMessage);
        }
    }
}
