<?php
/**
 * @copyright: Copyright © 2020 Firebear Studio GmbH. All rights reserved.
 */

namespace Firebear\PlatformSap\Observer;

use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Event\Observer as EventObserver;
use Magento\Customer\Model\ResourceModel\CustomerRepository;
use Firebear\PlatformSap\Model\Customer\UpdatePublisher;

class CustomerAccountEditedObserver implements ObserverInterface
{
    /**
     * @var UpdatePublisher
     */
    private $customerUpdatePublisher;

    /**
     * @var CustomerRepository
     */
    private $customerRepository;

    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;

    /**
     * CustomerAccountEditedObserver constructor.
     * @param UpdatePublisher $orderUpdatePublisher
     * @param CustomerRepository $customerRepository
     * @param ScopeConfigInterface $scopeConfig
     */
    public function __construct(
        UpdatePublisher $orderUpdatePublisher,
        CustomerRepository $customerRepository,
        ScopeConfigInterface $scopeConfig
    ) {
        $this->customerUpdatePublisher = $orderUpdatePublisher;
        $this->customerRepository = $customerRepository;
        $this->scopeConfig = $scopeConfig;
    }

    /**
     * @param EventObserver $observer
     */
    public function execute(EventObserver $observer)
    {
        if ($this->scopeConfig->getValue('firebear_importexport/sap/export_customers')) {
            $email = $observer->getEvent()->getEmail();
            $customer = $this->customerRepository->get($email);
            $this->customerUpdatePublisher->execute($customer);
        }
    }
}
