<?php
/**
 * @copyright: Copyright © 2021 Firebear Studio. All rights reserved.
 * @author   : Firebear Studio <fbeardev@gmail.com>
 */
namespace Firebear\PlatformSap\Observer;

use Firebear\PlatformSap\Model\Order\UpdatePublisher;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\Event\Observer as EventObserver;
use Magento\Framework\Event\ObserverInterface;

class SalesOrderInvoicePay implements ObserverInterface
{
    /**
     * @var UpdatePublisher
     */
    private $orderUpdatePublisher;

    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;

    /**
     * CheckoutSubmitAllAfterObserver constructor.
     * @param UpdatePublisher $orderUpdatePublisher
     * @param ScopeConfigInterface $scopeConfig
     */
    public function __construct(
        UpdatePublisher $orderUpdatePublisher,
        ScopeConfigInterface $scopeConfig
    ) {
        $this->orderUpdatePublisher = $orderUpdatePublisher;
        $this->scopeConfig = $scopeConfig;
    }

    /**
     * @param EventObserver $observer
     */
    public function execute(EventObserver $observer)
    {
        if ($this->scopeConfig->getValue('firebear_importexport/sap/sap_export_orders')) {
            $invoice = $observer->getEvent()->getInvoice();
            $order = $invoice->getOrder();
            if ($order) {
                $this->orderUpdatePublisher->execute($order->getEntityId());
            }
        }
    }
}
